Reference
=========

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   cmd
   download
   checks
   install
   terminal_commands/init
   terminal_commands/posix
   terminal_commands/windows
   post_install/detect_providers
   post_install/providers/init
   post_install/providers/cloudflare
   post_install/providers/netlify
   post_install/providers/vercel
